@@ -145,7 +145,7 @@ class WandbWrapper:
 
     @staticmethod
     def add_histogram(tag, values, global_step):
-        if len(values) == 2:
+        if isinstance(values, (tuple, list)) and len(values) == 2:
             wandb.log({tag: wandb.Histogram(np_histogram=values)}, step=global_step, commit=False)
         else:
             wandb.log({tag: wandb.Histogram(values)}, step=global_step, commit=False)
